==> python-apptools-4.5.0-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/apptools/logger/agent/tests/test_attachments.py <==
from email.mime.multipart import MIMEMultipart
import io
import os
import shutil
import tempfile
import unittest

try:
    # On Python 3, mock is part of the standard library,
    from unittest import mock
except ImportError:
    # Whereas on Python 2 it is not.
    import mock

from apptools.logger.agent.attachments import Attachments


class AttachmentsTestCase(unittest.TestCase):
    def setUp(self):
        self.tmpdir = tempfile.mkdtemp()
        self.addCleanup(shutil.rmtree, self.tmpdir)

        self.tmpfile = os.path.join(self.tmpdir, "dummy_file.txt")
        with io.open(self.tmpfile, 'w', encoding='utf8') as filehandle:
            filehandle.write(u"Dummy data in dummy file for dummies")

    def test_attaching_workspace(self):
        class DummyWorkspace(object):
            path = self.tmpdir

        class MockedApplication(object):
            tmpdir = self.tmpdir
            def get_service(self, service_id):
                return DummyWorkspace()

        attachments = Attachments(
            application=MockedApplication(),
            message=MIMEMultipart()
        )
        attachments.package_workspace()

        message = attachments.message
        self.assertTrue(message.is_multipart())
        payload = message.get_payload()
        self.assertEqual(len(payload), 1)

    def test_attaching_single_project(self):
        class DummySingleProject(object):
            location = self.tmpdir

        class MockedApplication(object):
            tmpdir = self.tmpdir
            def get_service(self, service_id):
                return DummySingleProject()

        attachments = Attachments(
            application=MockedApplication(),
            message=MIMEMultipart()
        )
        attachments.package_single_project()

        message = attachments.message
        self.assertTrue(message.is_multipart())
        payload = message.get_payload()
        self.assertEqual(len(payload), 1)

==> python-apptools-5.2.0-2-any.pkg.tar.xz: usr/lib/python3.11/site-packages/apptools/logger/agent/tests/test_attachments.py <==
# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!
from email.mime.multipart import MIMEMultipart
import io
import os
import shutil
import tempfile
import unittest

from apptools.logger.agent.attachments import Attachments


class AttachmentsTestCase(unittest.TestCase):
    def setUp(self):
        self.tmpdir = tempfile.mkdtemp()
        self.addCleanup(shutil.rmtree, self.tmpdir)

        self.tmpfile = os.path.join(self.tmpdir, "dummy_file.txt")
        with io.open(self.tmpfile, "w", encoding="utf8") as filehandle:
            filehandle.write("Dummy data in dummy file for dummies")

    def test_attaching_workspace(self):
        class DummyWorkspace(object):
            path = self.tmpdir

        class MockedApplication(object):
            tmpdir = self.tmpdir

            def get_service(self, service_id):
                return DummyWorkspace()

        attachments = Attachments(
            application=MockedApplication(), message=MIMEMultipart()
        )
        attachments.package_workspace()

        message = attachments.message
        self.assertTrue(message.is_multipart())
        payload = message.get_payload()
        self.assertEqual(len(payload), 1)

    def test_attaching_single_project(self):
        class DummySingleProject(object):
            location = self.tmpdir

        class MockedApplication(object):
            tmpdir = self.tmpdir

            def get_service(self, service_id):
                return DummySingleProject()

        attachments = Attachments(
            application=MockedApplication(), message=MIMEMultipart()
        )
        attachments.package_single_project()

        message = attachments.message
        self.assertTrue(message.is_multipart())
        payload = message.get_payload()
        self.assertEqual(len(payload), 1)
